@@ -51,15 +51,17 @@ gpppon reads the names of providers from\n\
 /etc/ppp/peers. gpppon calls the pon\n\
 script with the selected provider name as argument.";
 
-static gchar helptxt[] = "Select a provider from the combo-box\n\
+
+static gchar helptxt[] = "Select a provider from the combo-box\n\ 
 Press ppp-on to start the ppp connection. To terminate\n\
 the connection just press ppp-off. This program does\n\
-not check whether or not ppp connection is actually\n\
+not check whether or not the ppp connection is actually\n\
 up. As it may take some time to dial in or terminate\n\
 the connection you should not switch too fast between\n\
 ppp-on and ppp-off.";
+/* " This is here because emacs has buggy syntax coloring */
 
-static int gppp_state = 0;	/*0 unknown, 1 ppp on, 2 ppp off */
+static int gppp_state = 0;	/* 0 unknown, 1 ppp on, 2 ppp off */
 
 /* this is because I am lazy */
 static GtkWidget *mw_txt_label;
@@ -71,10 +73,17 @@ get_provider_names ()
   static GList *list;
   char *string;
   int i = 0;
+  int error;
   DIR *peers;
   struct dirent *entry;
   list = NULL;
+
   peers = opendir ("/etc/ppp/peers");
+  if (!peers) {
+    perror ("Gpppon: /etc/ppp/peers");
+    gtk_exit (1);
+  }
+    
   while ((entry = readdir (peers)))
     {
       if (isgraph (entry->d_name[0]) && entry->d_name[0] != '.')
@@ -85,7 +94,13 @@ get_provider_names ()
 	}
       i++;
     }
-  closedir (peers);
+
+  error = closedir (peers);
+  if (error) {
+    perror ("Gpppon:");
+    gtk_exit (1);
+  }
+
   if (i == 0)
     {
       list = g_list_append (list, string);
